Skip to contents

Check the community dataset for all-zero taxa and empty levels and filter them out.

Usage

reduce_data(data_source_reduce, check_taxa = TRUE, check_levels = TRUE)

Arguments

data_source_reduce

list with community, age, and age_un

check_taxa

logical. Should columns be checked for all-zero taxa?

check_levels

logical. Should rows be checked for empty levels?

Value

The input list with redundant columns and rows removed.