Skip to contents

Apply one of five smoothing methods to each taxon in the community data before RoC is computed.

Usage

smooth_community_data(
  data_source_smooth,
  smooth_method = c("m.avg", "grim", "age.w", "shep"),
  smooth_n_points = 5,
  smooth_n_max = 9,
  smooth_age_range = 500,
  round_results = FALSE,
  verbose = FALSE,
  silent = FALSE
)

Arguments

data_source_smooth

List with community, and age

smooth_method

character. Smoothing method applied to each taxon before RoC is computed.

  • "none" - no smoothing (default)

  • "shep" - Shepard's 5-term filter (Davis, 1986; Wilkinson, 2005)

  • "m.avg" - moving average

  • "age.w" - age-weighted average

  • "grim" - Grimm's smoothing (Grimm & Jacobson, 1992)

smooth_n_points

numeric. Number of points used for moving average, Grimm, and age-weighted smoothing. Must be an odd number.

smooth_n_max

numeric. Maximum number of samples included in a Grimm smoothing window.

smooth_age_range

numeric. Maximum age range (in years) for Grimm and age-weighted smoothing windows.

round_results

Logical. Should smoothed values be rounded to integers?

verbose

logical. If TRUE, print progress messages during computation.

silent

logical. If TRUE, suppress all console output (overrides verbose).

Value

The input list with the community element replaced by the smoothed values.

References

Davis, J.C., 1986. Statistics and Data Analysis in Geology, 2nd edn. J. Wiley & Sons, New York.

Grimm, E.C., Jacobson, G.L., 1992. Fossil-pollen evidence for abrupt climate changes during the past 18000 years in eastern North America. Clim. Dyn. 6, 179-184.

Wilkinson, L., 2005. The Grammar of Graphics. Springer-Verlag, New York.

See also