Skip to contents

Rarefy each Working Unit to n_individuals by sampling without replacement.

Usage

standardise_community_data(data_source_standard, n_individuals = 150)

Arguments

data_source_standard

Data.frame with taxons as columns

n_individuals

numeric. Number of individuals to rarefy to when standardise = TRUE. Automatically reduced to the smallest count in the sequence if any WU has fewer individuals.

Value

The input data.frame with counts replaced by rarefied values.