Skip to contents

Select one representative level per bin according to bin_selection.

Usage

subset_samples(data_source_subset, data_source_bins, bin_selection = "first")

Arguments

data_source_subset

data.frame with community data.

data_source_bins

data.frame defining individual Working Units.

bin_selection

character. Rule for selecting one level from each bin.

  • "random" (default) - a level is selected at random.

  • "first" - the level closest to the start of the bin is selected.

Value

A data.frame with one row per Working Unit.