Plot the Rate-of-Change sequence (deprecated)
Source:R/fc_plot_RoC_sequence.R
fc_plot_RoC_sequence.RdThis function was deprecated, please use plot_roc().
Usage
fc_plot_RoC_sequence(
data_source,
age_threshold = NULL,
roc_threshold = NULL,
Roc_threshold = lifecycle::deprecated(),
peaks = FALSE,
Peaks = lifecycle::deprecated(),
trend = NULL
)Arguments
- data_source
tibble. Output ofestimate_roc()ordetect_peak_points().- age_threshold
numeric. Optional. Upper (oldest) age cut-off; samples older than this value are excluded from the plot.- roc_threshold
numeric. Optional. Upper RoC cut-off; values above this are clipped.- Roc_threshold
Roc_thresholdis no longer supported; please useroc_threshold- peaks
logical. IfTRUEand aPeakcolumn is present indata_source, peak points are highlighted on the plot (default =FALSE).- Peaks
- trend
characterorNULL. Whenpeaks = TRUE, optionally overlay the trend curve used during peak detection. One of"threshold","trend_linear", or"trend_non_linear".NULL(default) shows no trend line.